@@ -2,15 +2,10 @@ package uk.ac.cam.ch.wwmm.oscar.obo.dso;
 
 import org.junit.Assert;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-
-import ch.unibe.jexample.Given;
-import ch.unibe.jexample.JExample;
 
 import uk.ac.cam.ch.wwmm.oscar.obo.OBOOntology;
 import uk.ac.cam.ch.wwmm.oscar.tools.ResourceGetter;
 
-@RunWith(JExample.class)
 public class DSOtoOBOTest {
 
 	@Test
@@ -21,8 +16,8 @@ public class DSOtoOBOTest {
 		);
 		Assert.assertNotNull(rg.getStream("ptcontology.dso"));
 	}
-	
-	@Given("testLoadingDSOFile")
+
+	@Test
 	public void testReadDSO() throws Exception {
 		OBOOntology obo = DSOtoOBO.readDSO();
 		Assert.assertNotNull(obo);
